@@ -124,6 +124,15 @@ type Proxy struct {
 
 const maxConnectAttempts = 3
 
+// IsConnected returns a channel that signals the proxy has finished connecting.
+// can only be called after webSocketClient is initialized
+func (p *Proxy) IsConnected() <-chan struct{} {
+	for p.webSocketClient == nil {
+		time.Sleep(50 * time.Millisecond)
+	}
+	return p.webSocketClient.Connected()
+}
+
 // Run sets the websocket connection and starts the Goroutines to forward
 // incoming events to the local endpoint.
 func (p *Proxy) Run(ctx context.Context) error {
@@ -484,22 +493,26 @@ func Init(ctx context.Context, cfg *Config) (*Proxy, error) {
 		if err != nil {
 			return nil, err
 		}
-	} else if len(cfg.ForwardURL) > 0 {
-		// non-connect endpoints
-		endpointRoutes = append(endpointRoutes, EndpointRoute{
-			URL:            parseURL(cfg.ForwardURL),
-			ForwardHeaders: cfg.ForwardHeaders,
-			Connect:        false,
-			EventTypes:     cfg.Events,
-		})
+	} else {
+		if len(cfg.ForwardURL) > 0 {
+			// non-connect endpoints
+			endpointRoutes = append(endpointRoutes, EndpointRoute{
+				URL:            parseURL(cfg.ForwardURL),
+				ForwardHeaders: cfg.ForwardHeaders,
+				Connect:        false,
+				EventTypes:     cfg.Events,
+			})
+		}
 
-		// connect endpoints
-		endpointRoutes = append(endpointRoutes, EndpointRoute{
-			URL:            parseURL(cfg.ForwardConnectURL),
-			ForwardHeaders: cfg.ForwardConnectHeaders,
-			Connect:        true,
-			EventTypes:     cfg.Events,
-		})
+		if len(cfg.ForwardConnectURL) > 0 {
+			// connect endpoints
+			endpointRoutes = append(endpointRoutes, EndpointRoute{
+				URL:            parseURL(cfg.ForwardConnectURL),
+				ForwardHeaders: cfg.ForwardConnectHeaders,
+				Connect:        true,
+				EventTypes:     cfg.Events,
+			})
+		}
 	}
 
 	p := &Proxy{
